findConfFile: find config file

View source: R/batchtools_config_template.R

findConfFileR Documentation

find config file

Description

Find a default config file. First calls batchtools::findConfFile and then find a pulsar default.

Usage

findConfFile(name = "")

Arguments

name

name of default config or path to config file.

Details

See the batchtools functions batchtools::findConfFile and batchtools::makeRegistry. When calling batch.pulsar, we attempt to use batchtool's default lookup for a config file before calling pulsar::findConfFile.

For clusters with a queuing submission system, a template file, for defining worker node resources and executing the batch R code, will need to be defined somewhere on the system. See findTemplateFile.

See Also

findTemplateFile

Examples

if (requireNamespace("batchtools", quietly = TRUE)) {
  ## Default config file provided by pulsar runs code in interactive mode
  ## This is for testing purposes and executes serially.
  findConfFile()
  ## Use the parallel package
  ## slower than providing the 'ncores' argument to pulsar function, due to
  ## the overhead of creating the batchtools registry.
  findConfFile('parallel')

  ## Use the snow package to register/execute batch jobs on socket clusters.
  findConfFile('snow')
  ## Use a TORQUE / PBS queing system. Requires brew template file.
  findConfFile('torque')
  findTemplateFile('simpletorque')
}


pulsar documentation built on March 29, 2026, 9:09 a.m.