getLamPath: Lambda path

View source: R/utilities.R

getLamPathR Documentation

Lambda path

Description

Generate a lambda path sequence in descending order, equally or log-spaced.

Usage

getLamPath(max, min, len, log = FALSE)

Arguments

max

numeric, maximum lambda value

min

numeric, minimum lambda value

len

numeric/int, length of lambda path

log

logical, should the lambda path be log-spaced

Value

numeric vector of lambdas

See Also

getMaxCov

Examples

if (requireNamespace("huge", quietly = TRUE)) {
  library(huge)
  set.seed(10010)
  p <- 40 ; n <- 100
  dat   <- huge.generator(n, p, "hub", verbose=FALSE, v=.1, u=.3)

  ## Theoretical lambda max is the maximum abs value of the empirical covariance matrix
  maxCov <- getMaxCov(dat$data)
  lams   <- getLamPath(maxCov, 5e-2*maxCov, len=40)
}

pulsar documentation built on March 29, 2026, 9:09 a.m.